#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-wai
version:              0.12.0
visibility:           public
id:                   hspec-wai-0.12.0-6kk4Z70SfszImRywuhvl2h
key:                  hspec-wai-0.12.0-6kk4Z70SfszImRywuhvl2h
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Experimental Hspec support for testing WAI applications
description:          Experimental Hspec support for testing WAI applications
category:             Testing
abi:                  80b5d7af8ae5324ac45ed41f28ec7bd8
exposed:              True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck

hidden-modules:       Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-wai-0.12.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-wai-0.12.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-wai-0.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai
hs-libraries:         HShspec-wai-0.12.0-6kk4Z70SfszImRywuhvl2h
depends:
    QuickCheck-2.15.0.1-3mU9ZiusQQy5d3HGk3bpZl base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-CbvbZydH4uCGBf3Bqda73d
    hspec-core-2.11.7-2RMDdDQOJIS9Jlv3hUAFzy
    hspec-expectations-0.8.4-JRz47SURfXgGxfIuVeuxEa
    http-types-0.12.4-D4ln0jiwEOhAKcR3fqSchY text-2.0.2
    transformers-0.6.1.0 wai-3.2.4-HOJRNxSLXyTJ5Lq7jmcw5j
    wai-extra-3.1.18-B7EWthatwHjJCstJt9IxKf

haddock-interfaces:   /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html:         /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

